Trait ModbusInputRegister

pub trait ModbusInputRegister: ModbusParam {
    // Required method
    fn decode_from_input_register(words: &[Word]) -> Result<Self, Error>;
}
Input registers are used to indicate the present values of the measured and calculated electrical quantities. Modbus Protocol function code 04 is used to access all parameters.

Not: Each request for data must be restricted to 30 parameters or less. Exceeding the 30 parameter limit will cause a Modbus Protocol exception code to be returned.

Required Methods

fn decode_from_input_register(words: &[Word]) -> Result<Self, Error>

Decode from a Modbus input register into Self. This decoding is used to read data from the device.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors